@@ -17,33 +17,32 @@ class BBBDLC:
         }
 
         try:
-            serverName = args.serverName
             serverDir = args.serverDir
-            
-            while (serverDir != "/" and os.path.basename(serverDir) != serverName):
-                serverDir = os.path.dirname(serverDir)
-            
-            if serverDir == "/": raise NameError('Could not find nextcloud folder!')
-            serverDir += "/nextcloud"
 
             os.chdir(serverDir)
 
-            occCommand = "/opt/plesk/php/7.3/bin/php " + serverDir + "/occ "
+            occCommand = "sudo -u adminroot /opt/plesk/php/7.3/bin/php " + serverDir + "/occ "
             os.system(occCommand + "config:system:get datadirectory > ncPath.txt")
 
             ncPathFile = open(serverDir + "/ncPath.txt", "r")
             ncPath = ncPathFile.readline().strip()
-            ncPathFile.close()
-            os.system("rm " + serverDir + "/ncPath.txt")
 
-            if ncPath == "": raise NameError('Could not find nextcloud config!')
+            if ncPath == "":
+                raise NameError('No nextcloud path specified!')
+            elif not os.path.isdir(ncPath):
+                raise NameError('Invalid nextcloud path specified!\n' + ncPathFile.read())
+            else:
+                ncPathFile.close()
+                os.system("rm " + serverDir + "/ncPath.txt")
+            
+            
             
             recordingUrl = bbb.get_recordings(recordingParams)
             recordingUrl = recordingUrl["xml"]["recordings"]["recording"]["playback"]["format"]["url"]
             passthroughArgs = ""
 
             for arg in vars(args):
-                if arg == "recordId" or arg == "server" or arg == "secret" or arg == "serverName" or arg == "serverDir": continue
+                if arg == "recordId" or arg == "server" or arg == "secret" or arg == "serverDir": continue
                 if getattr(args, arg) == None or getattr(args, arg) == False: continue
 
                 arg = arg.replace("_", "-")
@@ -52,7 +51,7 @@ class BBBDLC:
 
             passthroughArgs += recordingUrl
             os.chdir(ncPath + "/admin/files")
-            os.system("ianes-bbb-dl " + passthroughArgs)
+            os.system("sudo -u adminroot ianes-bbb-dl " + passthroughArgs)
             os.system(occCommand + "files:scan admin")
         except Exception as e:
             now = datetime.now()
@@ -85,8 +84,6 @@ def get_parser():
         description=('Big Blue Button Converter and Downloader')
     )
 
-    parser.add_argument('serverName', type=str, help='Server name')
-
     parser.add_argument('serverDir', type=str, help='Server install directory')
 
     parser.add_argument('recordId', type=str, help='Recording ID of a lesson')
